@@ -251,7 +251,7 @@ class ApplicationController < ActionController::Base
     end
     if lang.nil? && !Setting.force_default_language_for_anonymous? && request.env['HTTP_ACCEPT_LANGUAGE']
       accept_lang = parse_qvalues(request.env['HTTP_ACCEPT_LANGUAGE']).first
-      if !accept_lang.blank?
+      if accept_lang.present?
         accept_lang = accept_lang.downcase
         lang = find_language(accept_lang) || find_language(accept_lang.split('-').first)
       end
@@ -408,7 +408,7 @@ class ApplicationController < ActionController::Base
     raise ActiveRecord::RecordNotFound if @issues.empty?
     raise Unauthorized unless @issues.all?(&:visible?)
 
-    @projects = @issues.collect(&:project).compact.uniq
+    @projects = @issues.filter_map(&:project).uniq
     @project = @projects.first if @projects.size == 1
   rescue ActiveRecord::RecordNotFound
     render_404
@@ -555,7 +555,7 @@ class ApplicationController < ActionController::Base
     else
       if args.any?
         redirect_to *args
-      elsif block_given?
+      elsif block
         yield
       else
         raise "#redirect_to_referer_or takes arguments or a block"
